package com.ruoyi.bar.mapper;

import com.ruoyi.common.core.domain.entity.WyBarUserRole;

import java.util.List;

/**
 * 品牌方用户和角色关联Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-04
 */
public interface WyBarUserRoleMapper 
{
    /**
     * 查询品牌方用户和角色关联
     * 
     * @param userId 品牌方用户和角色关联主键
     * @return 品牌方用户和角色关联
     */
    public WyBarUserRole selectWyBarUserRoleByUserId(Long userId);

    /**
     * 查询品牌方用户和角色关联列表
     * 
     * @param wyBarUserRole 品牌方用户和角色关联
     * @return 品牌方用户和角色关联集合
     */
    public List<WyBarUserRole> selectWyBarUserRoleList(WyBarUserRole wyBarUserRole);

    /**
     * 新增品牌方用户和角色关联
     * 
     * @param wyBarUserRole 品牌方用户和角色关联
     * @return 结果
     */
    public int insertWyBarUserRole(WyBarUserRole wyBarUserRole);

    /**
     * 修改品牌方用户和角色关联
     * 
     * @param wyBarUserRole 品牌方用户和角色关联
     * @return 结果
     */
    public int updateWyBarUserRole(WyBarUserRole wyBarUserRole);

    /**
     * 删除品牌方用户和角色关联
     * 
     * @param userId 品牌方用户和角色关联主键
     * @return 结果
     */
    public int deleteWyBarUserRoleByUserId(Long userId);

    /**
     * 批量删除品牌方用户和角色关联
     * 
     * @param userIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBarUserRoleByUserIds(Long[] userIds);

    void batchUserRole(List<WyBarUserRole> list);
}
